/******************************************************************************
*
* These TV POWER codes were compiled by Mitch Altman/Cornfield Electronics 
* for use with his TV-B-Gone product (http://www.tvbgone.com). In 2007, Mitch 
* joined forces with Limor Fried to release a kit version along with source 
* (http://www.ladyada.net/make/tvbgone/index.html). The portions used in this
* DC16 badge are distributed under Creative Commons 2.5 -- Attib & Share Alike
*
* Says Mitch from the TV-B-Gone kit main.c:
* "The tricky part of TV-B-Gone was collecting all of the POWER codes, and 
* getting rid of the duplicates and near-duplicates (because if there is a 
* duplicate, then one POWER code will turn a TV off, and the duplicate will 
* turn it on again (which we certainly do not want)."
*
* Thanks to Albert Yarusso (http://www.atariage.com) for helping with porting
* and debugging.
*
*******************************************************************************/
#include "FslTypes.h"
#include "DC16.h"

  
// Code 000 -- Sony, Baur, Neckermann, Otto Versand, Palladium, Quelle, SEI, Sinudyne, Sonolor, Universum
static const powercode sonyCode  = {
  freq_to_timerval(37470), // 37.47 KHz  
  {{245, 60},
   {123, 60},
   {61 , 60},
   {123, 60},
   {61 , 60},
   {123, 60},
   {61 , 60},
   {61 , 60},
   {123, 60},
   {61 , 60},
   {61 , 60},
   {61 , 60},
   {61 , 2759},
   {245, 60},
   {123, 60},
   {61 , 60},
   {123, 60},
   {61 , 60},
   {123, 60},
   {61 , 60},
   {61 , 60},
   {123, 60},
   {61 , 60},
   {61 , 60},
   {61 , 60},
   {61 , 0}// end of code
  }
};

//Code 001 - Proscan, RCA, Curtis Mathes, Dimensia, GE, JC Penney, LXI, Radio Shack/Realistic, Sears, Wards
static const powercode rcaCode  = {
  freq_to_timerval(55600), // 55.6 KHz  
  {{ 411,   410 },
   {  52,   205 },
   {  52,   205 },
   {  52,   205 },
   {  52,   205 },
   {  52,   102 },
   {  52,   102 },
   {  52,   205 },
   {  52,   102 },
   {  52,   205 },
   {  52,   102 },
   {  52,   205 },
   {  52,   102 },
   {  52,   102 },
   {  52,   102 },
   {  52,   102 },
   {  52,   102 },
   {  52,   205 },
   {  52,   205 },
   {  52,   102 },
   {  52,   205 },
   {  52,   102 },
   {  52,   205 },
   {  52,   102 },
   {  52,   205 },
   {  52,   821 },
   { 411,   410},
   {  52,   205},
   {  52,   205},
   {  52,   205},
   {  52,   205},
   {  52,   102},
   {  52,   102},
   {  52,   205},
   {  52,   102},
   {  52,   205},
   {  52,   102},
   {  52,   205},
   {  52,   102},
   {  52,   102},
   {  52,   102},
   {  52,   102},
   {  52,   102},
   {  52,   205},
   {  52,   205},
   {  52,   102},
   {  52,   205},
   {  52,   102},
   {  52,   205},
   {  52,   102},
   {  52,   205},
   {  52,   0}
  }
};

// Code 002 -- Panasonic
static const powercode panasonicCode  = {
  freq_to_timerval(36130), // 36.13 KHz
  {{ 358,   179 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,    45 },
   {  44,   135 },
   {  44,  7720 },
   { 358,   180 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,    45 },
   {  44,    45 },
   {  44,   135 },
   {  44,    45 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,   135 },
   {  44,    45 },
   {  44,   135 },
   {  44,     0 }}
};

// Code 003 -- Sharp
static const powercode sharpCode  = {
  freq_to_timerval( 37470), // 37.47 KHz
  {{  28,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,   189 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,  4670 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,   189 },
   {  29,   189 },
   {  29,   189 },
   {  29,    81 },
   {  29,   189 },
   {  29,  4670 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,   189 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,  4670 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,    81 },
   {  29,   189 },
   {  29,    81 },
   {  29,   189 },
   {  29,   189 },
   {  29,   189 },
   {  29,    81 },
   {  29,   189 },
   {  29,     0 }}
};

// Code 004 -- Toshiba, Apex
static const powercode toshibaCode  = {
  freq_to_timerval( 37470), // 37.47 KHz
  {{ 924,   464 },
   {  58,    57 },
   {  58,    57 },
   {  58,    57 },
   {  58,    57 },
   {  58,    57 },
   {  58,    57 },
   {  58,   173 },
   {  58,    57 },
   {  58,   173 },
   {  58,   173 },
   {  58,   173 },
   {  58,   173 },
   {  58,   173 },
   {  58,   173 },
   {  58,    57 },
   {  58,   173 },
   {  58,    57 },
   {  58,   173 },
   {  58,    57 },
   {  58,    57 },
   {  58,   173 },
   {  58,    57 },
   {  58,    57 },
   {  58,    57 },
   {  58,   173 },
   {  58,    57 },
   {  58,   173 },
   {  58,   173 },
   {  58,    57 },
   {  58,   173 },
   {  58,   173 },
   {  58,   173 },
   {  58,  4054 },
   { 926,   230 },
   {  58,  9880 },
   { 926,   230 },
   {  58,     0 },						       
  }
};

// Code 005 -- Philips, Grundig, Pye
static const powercode philipsCode  = {
  freq_to_timerval( 34800), // 34.8 KHz
  {  {  92,    92 },
     { 184,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,   184 },
     {  92,    92 },
     { 184,    92 },
     {  92,  9216 },
     {  92,    92 },
     { 184,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,    92 },
     {  92,   184 },
     {  92,    92 },
     { 184,    92 },
     {  92,     0 },
  }
};

// Code 006 -- Samsung
static const powercode samsungCode  = {
  freq_to_timerval( 37470), // 37.47 KHz
  {{ 462,   476 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,   175 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,   175 },
   {  53,    62 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,  4661 },
   { 464,   476 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,   175 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,    62 },
   {  53,   175 },
   {  53,    62 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,   175 },
   {  53,     0 },
  }
};

// Code 007 -- Zenith
static const powercode zenithCode  = {
  freq_to_timerval( 38200), 
  {{  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,    49 },
   {  52,   419 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,   522 },
   {  52,    49 },
   {  52, 12433 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,    49 },
   {  52,   419 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,    49 },
   {  52,   419 },
   {  52,   522 },
   {  52,   522 },
   {  52,    49 },
   {  52,     0 },
  }
};

// Code 008 --Pioneer, Sansui, Toshiba
static const powercode pioneerCode  = {
  freq_to_timerval( 37470), 
  {{924,  462},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,  173},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,  173},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59, 4117},
   {926,  459},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,  173},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,  173},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,  173},
   { 59,   59},
   { 59,  173},
   { 59,    0}}
};

// Code 009 -- Sylvania
static const powercode sylvaniaCode  = {
  freq_to_timerval( 37430), 
  {{924, 461},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 174},
   {56, 56},
   {56, 174},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 174},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 174},
   {56, 56},
   {56, 56},
   {56, 56},
   {56, 4055},
   {926, 230},
   {56, 9855},
   {926, 230},
   {56, 0}
  }
};

// Code 010 -- JVC
static const powercode jvcCode  = {
  freq_to_timerval( 37470), 
  { {865,	429},
    {53,	161},
    {53,	161},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	161},
    {53,	161},
    {53,	161},
    {53,	55},
    {53,	161},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	2347},
    {53,	161},
    {53,	161},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	161},
    {53,	161},
    {53,	161},
    {53,	55},
    {53,	161},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	2347},
    {53,	161},
    {53,	161},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	161},
    {53,	161},
    {53,	161},
    {53,	55},
    {53,	161},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	0}}
};

// Code 011 -- Hitachi
static const powercode hitachiCode  = {
  freq_to_timerval( 37470), 
  { {909,	452},
    {58,	55},
    {58,	55},
    {58,	55},
    {58,	55},
    {58,	175},
    {58,	55},
    {58,	175},
    {58,	55},
    {58,	175},
    {58,	175},
    {58,	175},
    {58,	175},
    {58,	55},
    {58,	175},
    {58,	55},
    {58,	175},
    {58,	175},
    {58,	175},
    {58,	175},
    {58,	55},
    {58,	175},
    {58,	55},
    {58,	55},
    {58,	55},
    {58,	55},
    {58,	55},
    {58,	55},
    {58,	175},
    {58,	55},
    {58,	175},
    {58,	175},
    {58,	175},
    {58,	4146},
    {910,	229},
    {58,	9597},
    {910,	229},
    {56,	0} }
};

// Code 012 -- Sampo
static const powercode sampoCode  = {
  freq_to_timerval( 37470), 
  { {342,	343},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	260},
    {85,	87},
    {85,	87},
    {85,	87},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	87},
    {85,	260},
    {85,	260},
    {85,	260},
    {85,	3366},
    {342,	344},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	260},
    {85,	87},
    {85,	87},
    {85,	87},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	87},
    {85,	260},
    {85,	87},
    {85,	87},
    {85,	260},
    {85,	260},
    {85,	260},
    {85,	0}}
};

// Code 013 -- Hisense
static const powercode hisenseCode  = {
  freq_to_timerval( 37520), 
  { {918,	459},
    {56,	55},
    {56,	55},
    {56,	170},
    {56,	170},
    {56,	170},
    {56,	55},
    {56,	55},
    {56,	55},
    {56,	170},
    {56,	55},
    {56,	55},
    {56,	55},
    {56,	55},
    {56,	170},
    {56,	170},
    {56,	55},
    {56,	55},
    {56,	55},
    {56,	170},
    {56,	170},
    {56,	170},
    {56,	55},
    {56,	170},
    {56,	170},
    {56,	170},
    {56,	170},
    {56,	55},
    {56,	170},
    {56,	55},
    {56,	55},
    {56,	170},
    {56,	55},
    {56,	55},
    {56,	55},
    {56,	170},
    {56,	55},
    {56,	170},
    {56,	170},
    {56,	55},
    {56,	170},
    {56,	170},
    {56,	170},
    {56,	2364},
    {920,	458},
    {56,	9620},
    {920,	458},
    {56,	0}}
};

// Code 014 -- Viewsonic, Acer
static const powercode viewsonicCode  = {
  freq_to_timerval( 37470), 
  { {924,	464},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	4054},
    {926,	230},
    {58,	9880},
    {926,	230},
    {58,	0}}
};

// Code 015 -- Bush, NET-TV
static const powercode bushCode  = {
  freq_to_timerval( 37470), 
  { {924,	464},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	4054},
    {926,	230},
    {58,	9880},
    {926,	230},
    {58,	0}}
};

// Code 016 -- AOC, Daewoo, Goldstar, JC Penney, LG, Memorex, MGA, 
// Mistubishi, MTC, NEC, Philco, Portland, RCA, Samsung, 
// Teknika, Vidtech, Wards, Yamaha
static const powercode aocCode  = {
  freq_to_timerval(33600), 
  { {30,	215},
    {30,	216},
    {30,	216},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	216},
    {30,	91},
    {30,	91},
    {30,	216},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	2573},
    {30,	216},
    {30,	216},
    {30,	216},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	216},
    {30,	91},
    {30,	91},
    {30,	216},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	91},
    {30,	0}}
};

// Code 017 -- Bell & Howell, Curtis Mathes, Emerson, Fisher, LXI, Memorex, 
// Radio Shack, Realistic, Sanyo, Sears, Toshiba
static const powercode bellCode  = {
  freq_to_timerval(38970), 
  { {924,	459},
    {59,	57},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	178},
    {59,	4260},
    {924,	231},
    {59,	9753},
    {924,	231},
    {59,	0}}
};

// Code 018 -- Pioneer, Hitachi
static const powercode pioneer2Code  = {
  freq_to_timerval(37470),
  { {873,	439},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	164},
    {53,	2633},
    {873,	440},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	164},
    {53,	2633},
    {873,	440},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	164},
    {53,	55},
    {53,	55},
    {53,	55},
    {53,	164},
    {53,	0}}
};

// Code 019 -- Fujitsu
static const powercode fujitsuCode  = {
  freq_to_timerval(37470),
  { {335,	166},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	4723},
    {336,	166},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	126},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	42},
    {43,	0}}
};


// Code 020 - Gold Star, JC Penney, LXI, Marantz, Memorex, Proton, Pulsar, 
// Toshiba, Wards

static const powercode goldstarCode  = {
  freq_to_timerval(37470),
  { {924,	472},
    {63,	55},
    {63,	55},
    {63,	166},
    {63,	55},
    {63,	55},
    {63,	55},
    {63,	55},
    {63,	55},
    {63,	166},
    {63,	166},
    {63,	55},
    {63,	166},
    {63,	166},
    {63,	166},
    {63,	166},
    {63,	166},
    {63,	55},
    {63,	55},
    {63,	55},
    {63,	166},
    {63,	55},
    {63,	55},
    {63,	55},
    {63,	55},
    {63,	166},
    {63,	166},
    {63,	166},
    {63,	55},
    {63,	166},
    {63,	166},
    {63,	166},
    {63,	166},
    {63,	4207},
    {926,	234},
    {63,	9957},
    {926,	234},
    {62,	0}}
};


// Code 021 - Daewoo, Emerson, Hitachi, RCA, White Westinghouse, Zenith
static const powercode daewooCode  = {
  freq_to_timerval(37470),
  { {821,	409},
    {51,	52},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	52},
    {51,	52},
    {51,	409},
    {51,	163},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	52},
    {51,	52},
    {51,	2397},
    {822,	409},
    {51,	52},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	52},
    {51,	52},
    {51,	409},
    {51,	163},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	163},
    {51,	52},
    {51,	52},
    {51,	52},
    {51,	0}}
};


// Code 022 - NEC
static const powercode NECCode  = {
  freq_to_timerval(37470),
  {
    {918,	460},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	179},
    {56,	179},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	179},
    {56,	179},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	61},
    {56,	179},
    {56,	179},
    {56,	179},
    {56,	179},
    {56,	179},
    {56,	179},
    {56,	179},
    {56,	179},
    {56,	61},
    {56,	61},
    {56,	4581},
    {921,	230},
    {56,	9705},
    {921,	230},
    {56,	0}
  }
};

// Code 023 - Admiral, Bell & Howell, Logik, Majestic, Memorex, 
// Montgomery Ward, Signature, Teknika, Wards, Zenith
static const powercode admiralCode  = {
  freq_to_timerval(39010),
  {
    {51,	516},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	10746},
    {51,	516},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	52},
    {51,	418},
    {51,	516},
    {51,	52},
    {51,	418},
    {51,	0}  }
};
// Code 024 - Sony
static const powercode sony2Code  = {
  freq_to_timerval(37470),
  { {245,	60},
    {123,	60},
    {123,	60},
    {123,	60},
    {123,	60},
    {61,	60},
    {123,	60},
    {61,	60},
    {123,	60},
    {61,	60},
    {61,	60},
    {61,	60},
    {61,	2636},
    {246,	60},
    {123,	60},
    {123,	60},
    {123,	60},
    {123,	60},
    {61,	60},
    {123,	60},
    {61,	60},
    {123,	60},
    {61,	60},
    {61,	60},
    {61,	60},
    {61,	0}  }
};

// Code 025 - Viewsonic, Magnavox, NET-TV, Electrograph, Gateway, Maxent, 
// NetTV, Sampo

static const powercode viewsonic2Code  = {
  freq_to_timerval(37470),
  {  {357,	358},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	3562},
    {358,	358},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	91},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	270},
    {88,	0},
  }
};


// Code 026 - Zenith
static const powercode zenith2Code  = {
  freq_to_timerval(38200),
  { {52,	49},
    {52,	419},
    {52,	522},
    {52,	49},
    {52,	419},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	522},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	49},
    {52,	12922},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	49},
    {52,	419},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	522},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	49},
    {52,	419},
    {52,	522},
    {52,	49},
    {52,	0}}
};


// Code 027 - Thompson
static const powercode thompsonCode  = {
  freq_to_timerval(55600),
  { {411,	410},
    {52,	102},
    {52,	205},
    {52,	205},
    {52,	205},
    {52,	102},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	102},
    {52,	102},
    {52,	205},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	821},
    {411,	410},
    {52,	102},
    {52,	205},
    {52,	205},
    {52,	205},
    {52,	102},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	102},
    {52,	102},
    {52,	205},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {52,	102},
    {52,	205},
    {51,	0}}
};

// Code 028  - Brillian, Sears
static const powercode brillianCode  = {
  freq_to_timerval(37430),
  { {267,	276},
    {123,	123},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	277},
    {123,	123},
    {123,	123},
    {123,	123},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	4876},
    {267,	277},
    {123,	123},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	277},
    {123,	123},
    {123,	123},
    {123,	123},
    {123,	277},
    {123,	123},
    {123,	277},
    {123,	0}}
};
// Code 029 - Magnavox
static const powercode magnavoxCode  = {
  freq_to_timerval(34800),
  { {92,	92},
    {184,	92},
    {92,	92},
    {92,	92},
    {92,	92},
    {92,	92},
    {92,	184},
    {184,	92},
    {92,	184},
    {92,	92},
    {184,	9216},
    {92,	92},
    {184,	92},
    {92,	92},
    {92,	92},
    {92,	92},
    {92,	92},
    {92,	184},
    {184,	92},
    {92,	184},
    {92,	92},
    {184,	0}}
};

// Code 030 - Viewsonic
static const powercode viewsonic3Code  = {
  freq_to_timerval(37470),
  { {924,	461},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	4055},
    {926,	230},
    {56,	9855},
    {926,	230},
    {56,	0}}
};

// Code 031 - Crown, Infinity, JBL, Loewe, LXI, Magnavox, Marantz, 
// Panaxonic, Philco, Philips, Sylvania, Wards
static const powercode crownCode  = {
  freq_to_timerval(34800),
  { {92,	91},
    {92,	91},
    {184,	91},
    {92,	91},
    {92,	91},
    {92,	91},
    {92,	91},
    {92,	91},
    {92,	182},
    {92,	91},
    {184,	91},
    {92,	9217},
    {92,	91},
    {92,	91},
    {184,	91},
    {92,	91},
    {92,	91},
    {92,	91},
    {92,	91},
    {92,	91},
    {92,	182},
    {92,	91},
    {184,	91},
    {92,	0}}
};

// Code 032 - Hitachi
static const powercode hitachi2Code  = {
  freq_to_timerval(37470),
  { {924,	461},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	56},
    {56,	174},
    {56,	56},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	174},
    {56,	4055},
    {926,	230},
    {56,	9855},
    {926,	230},
    {56,	0} }
};

// Code 033 - Fujitsu
static const powercode fujitsu2Code  = {
  freq_to_timerval(37470),
  { {344,	159},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	5438},
    {347,	157},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	124},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	43},
    {43,	0}}
};


// Code 034 - Hitachi
static const powercode hitachi3Code  = {
  freq_to_timerval(37470),
  { {924,	464},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	4054},
    {925,	230},
    {58,	9880},
    {925,	230},
    {58,	0}}
};


// Code 035 - NEC
static const powercode NEC2Code  = {
  freq_to_timerval(37470),
  { {924,	464},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	57},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	173},
    {58,	4054},
    {926,	230},
    {58,	9880},
    {926,	230},
    {58,	0} }
};

// Code 036 - Hitachi
static const powercode hitachi4Code  = {
  freq_to_timerval(40580),
  { {101,	94},
    {101,	94},
    {101,	94},
    {101,	293},
    {101,	94},
    {101,	293},
    {101,	94},
    {101,	293},
    {101,	94},
    {101,	94},
    {101,	3522},
    {101,	94},
    {101,	94},
    {101,	94},
    {101,	293},
    {101,	94},
    {101,	293},
    {101,	94},
    {101,	293},
    {101,	94},
    {101,	94},
    {101,	0}
  }
};

// Code 037 - Anam National, Electrohome, GE, Motorola, NEC, Panasonic, 
// Philco, Philips, Quasar, RCA, Tatung
static const powercode anamCode  = {
  freq_to_timerval(36090),
  { {88,	595},
    {88,	255},
    {88,	255},
    {88,	255},
    {88,	594},
    {88,	255},
    {88,	594},
    {88,	594},
    {88,	594},
    {88,	255},
    {88,	0}}
};

// Code 038 - AOC, NEC
static const powercode aoc2Code  = {
  freq_to_timerval(40580),
  { {530,	167},
    {42,	269},
    {42,	269},
    {42,	269},
    {170,	166},
    {42,	269},
    {170,	166},
    {170,	166},
    {42,	269},
    {42,	269},
    {42,	0} }
};

// Code 039 - Candle, Citizen, JC Penney, Magnavox, Philco, Philips, 
// Simpson, Soundesign, Sylvania, Teknika
static const powercode candleCode  = {
  freq_to_timerval(38970),
  { {924,	459},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	57},
    {59,	57},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	57},
    {59,	178},
    {59,	178},
    {59,	178},
    {59,	4262},
    {924,	231},
    {59,	9758},
    {924,	231},
    {59,	0}  
  }
};

// Code 040 - Contec/Cony, Emerson, Goldstar, Hitachi, JVC, Philco,
// Philips, Proton, Radio Shack/Realistic, Samsung, Scott,
// Sharp, Teknika
static const powercode contecCode  = {
  freq_to_timerval(54070),
  { {118,	 103},
    {708,	2778},
    {118,	 103},
    {708,	   0}
  }
};

// Code 041 - Contec/Cony, Hitachi, JC Penney, JVC, Sears, Teknika
static const powercode contec2Code  = {
  freq_to_timerval(38970),
  { {118,	 103},
    {118,	 103},
    {118,	 205},
    {118,	2778},
    {118,	 103},
    {118,	 103},
    {118,	 205},
    {118,	   0}
  }
};

// Code 042 - Sony
static const powercode sony3Code  = {
  freq_to_timerval(74940),
  { {250,	  63},
    {121,	  63},
    { 60,	  63},
    {121,	  63},
    { 60,	  63},
    {121,	  63},
    { 60,	  63},
    { 60,	  63},
    {121,	  63},
    { 60,	  63},
    { 60,	  63},
    { 60,	  63},
    { 60,	2819},
    {250,	  63},
    {121,	  63},
    { 60,	  63},
    {121,	  63},
    { 60,	  63},
    {121,	  63},
    { 60,	  63},
    { 60,	  63},
    {121,	  63},
    { 60,	  63},
    { 60,	  63},
    { 60,	  63},
    { 60,	   0}
  }
};

// Code 043 - Alleron, Emerson, Fujitsu, Funai, Grunpy, Scott, Sears, 
// Soundesign, Teknika, Wards

static const powercode alleronCode  = {
  freq_to_timerval(38970),
  { {924,	 431},
    { 56,	 173},
    { 56,	 173},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	 173},
    { 56,	  66},
    { 56,	 173},
    { 56,	  66},
    { 56,	 173},
    { 56,	 173},
    { 56,	 173},
    { 56,	 173},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	 173},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	  66},
    { 56,	 173},
    { 56,	 173},
    { 56,	 173},
    { 56,	  66},
    { 56,	 173},
    { 56,	 173},
    { 56,	 173},
    { 56,	 173},
    { 56,	4208},
    {924,	 231},
    { 56,	8899},
    {924,	 231},
    { 56,	   0}
  }
};

// Code 044 - Contec/Cony, Hitachi, JVC, Sears, Teknika

static const powercode contec3Code  = {
  freq_to_timerval(39010),
  { { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    {136,	  45},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	3583},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    {136,	  45},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	 123},
    { 46,	   0}
  }
};


// Code 045 - Curtis Mathes, Samsung
static const powercode curtisCode  = {
  freq_to_timerval(38970),
  { {444,	 446},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	  51},
    { 54,	 163},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	  51},
    { 54,	 163},
    { 54,	  51},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	 163},
    { 54,	4204},
    {908,	 224},
    { 54,	9767},
    {908,	 224},
    { 54,	   0}
  }
};

// Code 046 - Aiko, Citizen, Daewoo, Nikko, NTC, Portland, Teknika
static const powercode aikoCode  = {
  freq_to_timerval(37470),
  { {470,	 459},
    { 61,	  53},
    { 61,	 170},
    { 61,	 170},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	 170},
    { 61,	 170},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	 170},
    { 61,	 170},
    { 61,	 170},
    { 61,	 170},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	  53},
    { 61,	 170},
    { 61,	 170},
    { 61,	 170},
    { 61,	 170},
    { 61,	4612},
    {470,	 459},
    { 61,	 170},
    { 61,	9937},
    {470,	 459},
    { 61,	 170},
    { 61,	   0}
  }
};

// Code 047 - Daewoo
static const powercode daewoo2Code  = {
  freq_to_timerval(28670),
  { { 56,	  282},
    { 56,	  106},
    {108,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	 2592},
    { 56,	  282},
    { 56,	  106},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	13150},
    { 56,	  282},
    { 56,	  106},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	   52},
    { 56,	    0}
  }
};

// Code 048 - Electrohome, GE, JC Penney, MGA, Mitsubishi
static const powercode electrohomeCode  = {
  freq_to_timerval(38970),
  { {924,	  459},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	 4260},
    {924,	  231},
    { 59,	 9752},
    {924,	  231},
    { 59,	    0}
  }
};

// Code 049 - Emerson, Sharp
static const powercode emersonCode  = {
  freq_to_timerval(38970),
  { {444,	  446},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	   51},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	  163},
    { 54,	 4204},
    {908,	  224},
    { 54,	 9767},
    {908,	  224},
    { 54,	    0}
  }
};

// Code 050 - Fisher, MGA, Mitsubishi, Sears
static const powercode fisherCode  = {
  freq_to_timerval(44330),
  { {282,	 876},
    {282,	2038},
    {282,	2038},
    {282,	 876},
    {282,	 876},
    {282,	2038},
    {282,	 876},
    {282,	2038},
    {282,	2038},
    {282,	 876},
    {282,	   0}
  }
};


// Code 051 - Amplivision, Atlantic, Clatronic, Condor, Desnet, Formenti, 
// Hanseatic, Korting, Manesth, NEC, Orion, Otto Versand, 
// Pathe Cinema, Perdio, Phoenix, Sogera, Soundwave, Standard, 
// Technema, Telemeister, Televideon, Tensai, Tenson, Uher,
// Videotechnic, Vision, Watson, Weltblick, White Westinghouse

static const powercode amplivisionCode  = {
  freq_to_timerval(8860),
  { {  3,	   29},
    { 71,	   19},
    { 48,	   29},
    {  3,	13072},
    {  3,	   29},
    { 14,	   19},
    {  3,	   19},
    {  3,	   19},
    {  3,	   19},
    { 14,	   19},
    { 48,	   29},
    {  3,	    0}
  }
};

// Code 052 - GE, JC Penney, JVC, Midland, Panasonic, Prism, Quasar, 
// Techics, Techwood
static const powercode geCode  = {
  freq_to_timerval(54160),
  { {369,	  339},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	   89},
    { 83,	 3849},
    {369,	  339},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	   89},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	  260},
    { 83,	   89},
    { 83,	    0}
  }
};

// Code 053 - JVC
static const powercode jvc2Code  = {
  freq_to_timerval(38970),
  { {924,	  459},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 58,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 58,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	 4260},
    {924,	  231},
    { 59,	 9752},
    {924,	  231},
    { 59,	    0}
  }
};

// Code 054 - JVC
static const powercode jvc3Code  = {
  freq_to_timerval(38970),
  { {924,	  459},
    { 59,	  178},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	   57},
    { 59,	   57},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 59,	   57},
    { 59,	  178},
    { 59,	  178},
    { 58,	  178},
    { 59,	 4260},
    {924,	  231},
    { 59,	 9752},
    {924,	  231},
    { 59,	    0}
  }
};

// Code 055 - Kloss Novabeam, Magnavox, Philco, Philips, Sylvania, Wards
static const powercode klossCode  = {
  freq_to_timerval(54070),
  { { 53,	  237},
    { 53,	  812},
    { 53,	  237},
    { 53,	  812},
    { 53,	  237},
    { 53,	  812},
    { 53,	  237},
    { 53,	  524},
    { 53,	  524},
    { 53,	  237},
    { 53,	  237},
    { 53,	  237},
    { 53,	  237},
    { 53,	  524},
    { 53,	 2959},
    { 53,	  237},
    { 53,	  812},
    { 53,	  237},
    { 53,	  812},
    { 53,	  237},
    { 53,	  812},
    { 53,	  237},
    { 53,	  524},
    { 53,	  524},
    { 53,	  237},
    { 53,	  237},
    { 53,	  237},
    { 53,	  237},
    { 53,	  524},
    { 53,	    0}
  } 
};

const powercode *powerCodes[]  = {
  &sonyCode, &rcaCode, &panasonicCode, &sharpCode, &toshibaCode,
  &philipsCode, &samsungCode,&zenithCode, &pioneerCode, &sylvaniaCode,
  &jvcCode, &hitachiCode, &sampoCode, &hisenseCode, &viewsonicCode,
  &bushCode, &aocCode, &bellCode, &pioneer2Code, &fujitsuCode,
  &goldstarCode, &daewooCode, &NECCode, &admiralCode, &sony2Code,
  &viewsonic2Code, &zenith2Code, &thompsonCode, &brillianCode, &magnavoxCode,
  &viewsonic3Code, &crownCode, &hitachi2Code, &fujitsu2Code, &hitachi3Code,
  &NEC2Code, &hitachi4Code, &anamCode, &aoc2Code, &candleCode,
  &contecCode, &contec2Code, &sony3Code, &alleronCode, &contec3Code,
  &curtisCode, &aikoCode, &daewoo2Code, &electrohomeCode, &emersonCode,
  &fisherCode, &amplivisionCode, &geCode, &jvc2Code, &jvc3Code, &klossCode
};


unsigned char num_codes = (sizeof(powerCodes)/sizeof(*powerCodes));
